import React, { Component } from 'react'
import './style.scss'
import Redirect   from 'react-router/Redirect'
import Media from 'react-media'

import {
  Badge,
  Header,
  Layout,
  Drawer,
  Content,
  Navigation,
  Footer,
  FooterSection,
  FooterLinkList,
  Button
} from 'react-mdl'

export default class MainLayout extends Component {

  constructor(props) {
    super(props)
    this.handleWidth = 100;
     this.state = { height: 0, width: 0};
     this.updateWindowDimensions = this.updateWindowDimensions.bind(this);
   }

  updateWindowDimensions() {
    this.setState({ width: window.innerWidth, height: window.innerHeight });
  }

  componentDidMount() {
    this.updateWindowDimensions();
    window.addEventListener('resize', this.updateWindowDimensions.bind(this));
  }

  componentWillUnmount() {
    window.removeEventListener('resize', this.updateWindowDimensions.bind(this));
  }

  get menu () {
    if (!this.props.menu) {
      return [<a key={"menu/back"} styleName="menuItem"> Back </a>]
    }

    return this.props.menu.map(menuItem => {
      const badge = (menuItem.badge ? { text: menuItem.badge } : {})
      return (<a key={menuItem.id} href={menuItem.link} styleName="menuItem"> <Badge {...badge} >{ menuItem.title }</Badge> </a>)
    })
  }

  onLogout() {
    localStorage.removeItem('@carmel:authToken')
    this.setState({ loggedOut: true })
  }

  get actionMenu () {
    if (this.props.session.isLoggedIn) {
      return (<Button key={9999} raised ripple accent style={{marginLeft: "1rem"}}
                onClick={this.onLogout.bind(this)}>
        Logout
      </Button>)
    }
  }

  renderSmallLogo() {
    return (<a href="/" styleName="logo">
            <img src="/images/logo-small.jpg"/></a>)
  }

  renderLargeLogo() {
    return (<a href="/" styleName="logo">
            <img src="/images/logo.jpg"/></a>)
  }

  renderLogo() {
    if (this.state.width > 840) {
      return this.renderLargeLogo()
    }

    return this.renderSmallLogo()
  }

  renderHeader() {
    return (<Header transparent styleName="header">
    { this.renderLogo() }
      <Navigation styleName="menu">
        { this.menu }
      </Navigation>
      { this.actionMenu}
    </Header>)
  }

  renderDrawer() {
    return (<Drawer>
      <Navigation>
        { this.menu }
      </Navigation>
    </Drawer>)
  }

  render () {
    if (this.state.loggedOut) {
      window.location.reload()
      return (<Redirect to="/"/>)
    }

    return (<Layout fixedHeader>
            { this.renderHeader() }
            { this.renderDrawer() }
            <Content>
              <div styleName="container">
                { this.props.children}
              </div>
            </Content>
      </Layout>)
  }
}
